/*
 * Copyright (C) 2022, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#include <ukui-log4qt.h>

#include <QCoreApplication>
#include <QCommandLineOption>
#include <QCommandLineParser>
#include <QTranslator>
#include <QDebug>

#include "qtsinglecoreapplication.h"
#include "StatusManager/statusmanager.h"
#include "DbusManager/dbusservice.h"

int main(int argc, char *argv[])
{
    QtSingleCoreApplication a("kylin-status-manager", argc, argv);
    if (a.isRunning())
    {
        return EXIT_SUCCESS;
    }

    QTranslator translator;
    translator.load("usr/share/kylin-status-manager/zh.qm");
    a.installTranslator(&translator);

    QCommandLineParser parser;
    QCommandLineOption logOption("log", "open log");
    parser.addOption(logOption);
    parser.process(a);
    if (QCoreApplication::arguments().length() > 1) {
        QString opt = QCoreApplication::arguments().at(1);
        if (opt == "--log" || opt == "l"){
           qDebug() << "Termianl log";
        }
    }else {
        initUkuiLog4qt("kylin-status-manager");
    }
    StatusManager statusManagerInstance;
    DBusService dbus {&statusManagerInstance};
    statusManagerInstance.notifyStartupFinished();
    return a.exec();
}
